#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (C) 2012  Iñigo Serna
# Time-stamp: <2012-06-18 21:31:38 inigo>

u"""kindle_fb2png.py: convert Kindle 4 ereader screenshot from raw format to png

Copyright (C) 2012, Iñigo Serna <inigoserna@gmail.com>.
This software has been released under the GPL License version 3
see the COPYING file that comes with this package. There is NO WARRANTY.

Usage:\n\tkindle_fb2png.py  screenshot.raw [output.png]

To get the raw image file execute this command in your Kindle shell:
# dd if=/dev/fb0 of=./screenshot.raw bs=600 count=800

and then copy it to your computer where you run this script.
"""


import sys

import Image
import ImageOps


DIMENSIONS = (600, 800)


def main():
    if len(sys.argv) == 2:
        file_raw = sys.argv[1]
        file_out = file_raw + '.png'
    elif len(sys.argv) == 3:
        file_raw = sys.argv[1]
        file_out = sys.argv[2]
    else:
        print('Error: incorrect number of arguments\n')
        print(__doc__)
        sys.exit(-1)

    data = open(file_raw, 'rb').read()
    img = Image.frombuffer('L', DIMENSIONS, data, 'raw', 'L', 0, 1)
    img = ImageOps.invert(img)
    img.save(file_out, 'PNG')

    # WARNING: if we use:
    # img = Image.frombuffer('L', DIMENSIONS, data)
    # then this is needed:
    # img = img.transpose(Image.FLIP_TOP_BOTTOM)
    # or:
    # img = ImageOps.flip(img)


if __name__ == '__main__':
    main()
